import { getRequestAuthCode } from '@/utils/dingtalk'
import { login } from '@/api/login'
import { getUserinfo } from '@/api/member'
import { Toast } from 'vant'

const signatureStateEnum = ['待审核', '已通过', '已驳回']

const state = {
    name: '',
    schoolName: '深圳市第二特殊教育学校',
    mobile: '',
    userinfo: {},
    signatureStateText: '',  // 个签
    token: 'eyJ0eXAiOiJKV1QiLCJhbGciOiJIUzI1NiJ9.eyJ1aWQiOiI4NSIsImlzcyI6Imh0dHBzOlwvXC96YWluLmNvbSIsImF1ZCI6Imh0dHBzOlwvXC96YWluLmNvbSIsImlhdCI6MTY5ODMxMjI4NSwibmJmIjoxNjk4MzEyMjg1LCJleHAiOjE3MjQyMzIyODV9.ziAXs6DiZKGGjtPuaCZ6Vfpv6Ki_deZhFPnDDLjAJUg',
}

const getters = {
    getTags(state){
        if (!state.userinfo.title) return []
        let title = state.userinfo.title
        return title.split(',')
    },
    getDepartments (state) {
        let userinfo = state.userinfo
        if (!userinfo.department_list) return ''
        return userinfo.department_list.map(item => item.name).join('、')
    },

    // NOTE: 获取组织成员信息
    teamMemberInfomation (state, getters) {
        let values = [
            state.schoolName,
            state.name,
            getters.getTags.join('、')
        ]
        let labels = [
            '企业/组员',
            '姓名',
            '职务'
        ]
        return labels.map((label, index) => ({
            label,
            val: values[index]
        }))
    }
}

const mutations = {
    UPDATE_USER_DATA: (state, payload) => {
        const { mobile, name, subject } = payload.data
        state.userinfo = payload.data
        state.mobile = mobile
        state.name = name
        state.schoolName = subject
        state.signatureStateText = signatureStateEnum[payload.data.signature_status] || ''
    },
    // 更新用户Token
    UPDATE_USER_TOKEN: (state, payload) => (state.token = payload.token),
}

const actions = {
    async getUserInfo ({ commit }) {
        try {
            const result = await getUserinfo()
            if (result.code === 1) {
                const data = result.data
                // mobile	int			手机号  
                // name	string			姓名  
                // nickname	string		昵称  
                // headimg	string			头像地址  
                // title	string			职称  
                // department	string		部门（多个部门以逗号分隔）  
                // signature	string		个人签名  
                commit({
                    type: 'UPDATE_USER_DATA',
                    data
                })
            }
        } catch (error) {
            Toast({
                icon: 'error',
                message: error.message
            })
        }
    },

    // 登录获取token
    async login ({ dispatch, commit }) {
        try { 
            const code = await getRequestAuthCode()
            const result = await login(code)
            if (result.code === 1) {
                commit({
                    type: 'UPDATE_USER_TOKEN',
                    token: result.data
                })
                dispatch('getUserInfo')
            }
        } catch (error) {
            login
        }
    },
}

export default {
    namespaced: true,
    state,
    getters,
    mutations,
    actions
}